<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Activate Widget

add_action('widgets_init', 	array('NNRobots_Author_Box_Widget', 'register_widget'));

/**
 * NNRobots_Author_Box_Widget class.
 *
 * @extends WP_Widget
 */
class NNRobots_Author_Box_Widget extends WP_Widget {

	/**
	 * Register widget
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function register_widget() {
		register_widget( 'NNRobots_Author_Box_Widget' );
	}

	/**
	 * Register widget with WordPress.
	 *
	 * @access public
	 * @return void
	 */
	function __construct() {
		$control_ops = array('width' => 300, 'height' => 350);
		parent::__construct(
			'nnr-author-box', // Base ID
			__('Author Box', NNRobots_Author_Box::$text_domain), // Name
			array( 'description' => __( 'Display an author box to show off the current author.', NNRobots_Author_Box::$text_domain )), $control_ops // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		if ( is_singular() ) {

			echo $args['before_widget'];

			if (isset($instance['title'])) {
				$title = $instance[ 'title' ];
			} else {
				$title = '';
			}

			echo $args['before_title'] . $title . $args['after_title'];

			echo NNRobots_Author_Box::add_author_box('', true, NNRobots_Author_Box::$prefix_dash . 'widget');

			echo $args['after_widget'];

		}

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		if (isset($instance['title'])) {
			$title = $instance[ 'title' ];
		} else {
			$title = '';
		}

		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', NNRobots_Author_Box::$text_domain); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo isset($title) ? esc_attr( $title ) : ''; ?>" />
		</p>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

		return $instance;
	}

}